@@ -605,7 +605,7 @@ build_edit_event_window (void)
   GtkWidget *monthlylabelevery, *monthlyspin, *monthlylabels;
   GtkWidget *yearlylabelevery, *yearlyspin, *yearlylabels;
 
-  GtkWidget *scrolledwindowevent, *scrolledwindowalarm;
+  GtkWidget *scrolledwindowevent, *scrolledwindowalarm, *scrolledwindowrecur;
 
   GtkAdjustment *endspin_adj, *dailyspin_adj, *weeklyspin_adj,
                 *monthlyspin_adj, *yearlyspin_adj;
@@ -850,6 +850,11 @@ build_edit_event_window (void)
 
   vboxrepeattop = gtk_vbox_new (FALSE, 0);
 
+  scrolledwindowrecur = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindowrecur), vboxrepeattop);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindowrecur),
+                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+
   recurborder = gtk_frame_new (_("Type:"));
   gtk_box_pack_start (GTK_BOX (vboxrepeattop), recurborder,
                            TRUE, TRUE, 0);
@@ -931,23 +936,32 @@ build_edit_event_window (void)
 /* weekly hbox1 */
   weeklytable      = gtk_table_new (3, 3, FALSE);
   gtk_box_pack_start (GTK_BOX (s->weeklybox), weeklytable, FALSE, FALSE, 0);
+
+  gchar *gs;
+  
   for (i = 0; i < 3; i++)
     {
-      GtkWidget *b = gtk_check_button_new_with_label (nl_langinfo(days[i]));
+      gs = g_locale_to_utf8 (nl_langinfo(days[i]), -1, NULL, NULL, NULL);
+      GtkWidget *b = gtk_check_button_new_with_label (gs);
       gtk_table_attach_defaults (GTK_TABLE (weeklytable), b, i, i + 1, 0, 1);
       s->checkbuttonwday[i] = b;
+      g_free (gs);
     }
   for (i = 3; i < 6; i++)
     {
-      GtkWidget *b = gtk_check_button_new_with_label (nl_langinfo(days[i]));
+      gs = g_locale_to_utf8 (nl_langinfo(days[i]), -1, NULL, NULL, NULL);
+      GtkWidget *b = gtk_check_button_new_with_label (gs);
       gtk_table_attach_defaults (GTK_TABLE (weeklytable), b, i - 3, i - 2, 1, 2);
       s->checkbuttonwday[i] = b;
+      g_free(gs);
     }
   for (i = 6; i < 7; i++)
     {
-      GtkWidget *b = gtk_check_button_new_with_label (nl_langinfo(days[i]));
+      gs = g_locale_to_utf8 (nl_langinfo(days[i]), -1, NULL, NULL, NULL);
+      GtkWidget *b = gtk_check_button_new_with_label (gs);
       gtk_table_attach_defaults (GTK_TABLE (weeklytable), b, i - 6, i - 5, 2, 3);
       s->checkbuttonwday[i] = b;
+      g_free (gs);
     }
 
 /* monthly hbox */
@@ -1102,7 +1116,7 @@ build_edit_event_window (void)
                             labeleventpage);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebookedit), scrolledwindowalarm,
                             labelalarmpage);
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebookedit), vboxrepeattop,
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebookedit), scrolledwindowrecur,
                             labelrecurpage);
   gtk_widget_grab_focus (summaryentry);
 
@@ -1141,10 +1155,13 @@ build_edit_event_window (void)
   g_object_set_data_full (G_OBJECT (window), "edit_state", s,
                           destroy_user_data);
 
+  gtk_widget_show_all (vboxtop);
   recalculate_sensitivities (NULL, window);
 
   gpe_set_window_icon (window, "icon");
 
+  gtk_window_set_default_size (GTK_WINDOW (window), 240, 320);
+
   g_signal_connect (G_OBJECT (window), "delete_event",
                     G_CALLBACK (edit_finished), NULL);
 
